"use strict";
var React = require("react");
var EventEmitter = require("events");
var enzyme_1 = require("enzyme");
var BackgroundPanel_1 = require("../BackgroundPanel");
var TestUtils = require("react-addons-test-utils");
var backgrounds = [
    { name: "black", value: "#000000" },
    { name: "secondary", value: "rgb(123,123,123)" },
    { name: "tertiary", value: "rgba(123,123,123,.5)" },
    { name: "An image", value: "url(http://placehold.it/350x150)" },
];
var mockedApi = {
    getQueryParam: jest.fn(),
    setQueryParams: jest.fn(),
};
describe("Background Panel", function () {
    it("should exist", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = enzyme_1.shallow(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        expect(backgroundPanel).toBeDefined;
    });
    it("should have a default background value of transparent", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = enzyme_1.shallow(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        expect(backgroundPanel.state().backgrounds.length).toBe(0);
    });
    it("should show setup instructions if no colors provided", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = enzyme_1.shallow(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        expect(backgroundPanel.html().match(/Setup Instructions/gmi).length).toBeGreaterThan(0);
    });
    it("should set the query string", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        SpiedChannel.emit("background-set", backgrounds);
        expect(mockedApi.getQueryParam).toBeCalledWith("background");
    });
    it("should unset the query string", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        SpiedChannel.emit("background-unset", backgrounds);
        expect(mockedApi.setQueryParams).toBeCalledWith({ background: null });
    });
    it("should accept colors through channel and render the correct swatches with a default swatch", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        SpiedChannel.emit("background-set", backgrounds);
        expect(backgroundPanel.state.backgrounds[0].name).toBe(backgrounds[0].name);
        expect(backgroundPanel.state.backgrounds[2].value).toBe(backgrounds[2].value);
        var headings = TestUtils.scryRenderedDOMComponentsWithTag(backgroundPanel, "h4");
        expect(headings.length).toBe(10);
    });
    it("should allow setting a default swatch", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        var localBgs = backgrounds.slice();
        localBgs[0].default = true;
        SpiedChannel.emit("background-set", localBgs);
        expect(backgroundPanel.state.backgrounds[0].name).toBe(localBgs[0].name);
        expect(backgroundPanel.state.backgrounds[2].value).toBe(localBgs[2].value);
        var headings = TestUtils.scryRenderedDOMComponentsWithTag(backgroundPanel, "h4");
        expect(headings.length).toBe(8);
        delete backgrounds[0].default;
    });
    it("should allow the default swatch become the background color", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        var localBgs = backgrounds.slice();
        localBgs[1].default = true;
        SpiedChannel.on("background", function (bg) {
            expect(bg).toBe(localBgs[1].value);
        });
        SpiedChannel.emit("background-set", localBgs);
        expect(backgroundPanel.state.backgrounds[0].name).toBe(localBgs[0].name);
        expect(backgroundPanel.state.backgrounds[2].value).toBe(localBgs[2].value);
        var headings = TestUtils.scryRenderedDOMComponentsWithTag(backgroundPanel, "h4");
        expect(headings.length).toBe(8);
        delete backgrounds[1].default;
    });
    it("should unset all swatches on receiving the backgroun-unset message", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        SpiedChannel.emit("background-set", backgrounds);
        expect(backgroundPanel.state.backgrounds[0].name).toBe(backgrounds[0].name);
        expect(backgroundPanel.state.backgrounds[2].value).toBe(backgrounds[2].value);
        SpiedChannel.emit("background-unset");
        expect(backgroundPanel.state.backgrounds.length).toBe(0);
    });
    it("should pass the event from swatch clicks through the provided channel", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundPanel = TestUtils.renderIntoDocument(React.createElement(BackgroundPanel_1.default, {channel: SpiedChannel, api: mockedApi}));
        SpiedChannel.emit("background-set", backgrounds);
        var spy = jest.fn();
        SpiedChannel.on("background", spy);
        TestUtils.Simulate.click(TestUtils.scryRenderedDOMComponentsWithTag(backgroundPanel, "h4")[0]);
        expect(spy).toBeCalledWith(backgrounds[0].value);
    });
});
//# sourceMappingURL=BackgroundPanel.js.map